@@ -411,7 +411,7 @@ class FlowLogsApi(object):
         :type pretty: bool
         :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param offset: The first element (from the complete list of the elements) to include in the response (use together with limit for pagination).
+        :param offset: The first element (from the complete list of the elements) to include in the response (used together with <b><i>limit</i></b> for pagination).
         :type offset: int
         :param limit: The maximum number of elements to return (use together with offset for pagination).
         :type limit: int
@@ -453,7 +453,7 @@ class FlowLogsApi(object):
         :type pretty: bool
         :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param offset: The first element (from the complete list of the elements) to include in the response (use together with limit for pagination).
+        :param offset: The first element (from the complete list of the elements) to include in the response (used together with <b><i>limit</i></b> for pagination).
         :type offset: int
         :param limit: The maximum number of elements to return (use together with offset for pagination).
         :type limit: int
